@@ -5,7 +5,7 @@ use warnings;
 use Carp;
 use Module::CPANTS::Analyse;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
     my ($class, %opts) = @_;
@@ -49,6 +49,7 @@ sub lint {
         my $type = $ind->{is_extra} ? 'extra' :
                    $ind->{is_experimental} ? 'experimental' :
                    'core';
+        next if $type eq 'experimental' && !$self->{opts}{experimental};
         my $error = $err{$ind->{name}};
         if ($error && ref $error) {
             $error = $self->_dump($error);
@@ -219,6 +220,10 @@ Makes L<Module::CPANTS::Analyse> verbose. False by default.
 
 If true, the C<lint> method (see below) returns true even if C<extra> metrics (as well as C<experimental> metrics) fail. This may be useful if you only care Kwalitee rankings. False by default.
 
+=item experimental
+
+If true, failed C<experimental> metrics are also reported (via C<report> method). False by default. Note that C<experimental> metrics are not taken into account while calculating a score.
+
 =item save
 
 If true, C<output_report> method writes to a file instead of writing to STDOUT.
